@@ -24,8 +24,11 @@ lapply(
     test_that(paste0("Load from spec works for:", x$df), {
       df <- translate(x$file)
       orig <- eval(parse(text = x$original))
+      nm <- as.character(lapply(x$variables, function(x) x$trans))
+      nm[nm == "FALSE"] <- "n"
+      nm[nm == "TRUE"] <- "y"
       expect_is(df, "data.frame")
-      expect_equal(names(df), as.character(lapply(x$variables, function(x) x$trans)))
+      expect_equal(names(df), nm)
       expect_equal(nrow(orig), nrow(df))
       expect_equal(ncol(orig), ncol(df))
       expect_equal(class(orig), class(df))
